@@ -10,6 +10,7 @@ import warnings
 import numpy as np
 import multiprocessing as mp
 import time
+from tqdm import tqdm
 from seisloc.sta import load_sta
 warnings.filterwarnings("ignore")
 
@@ -171,7 +172,7 @@ def mp_day_split(i_path,o_path,sta_file,format="mseed",shift_hour=0,parallel=Tru
     status = True
     false_folder = []
     print("# Check the network and station name...")
-    for folder in folder_list:
+    for folder in tqdm(folder_list):
         file_list=os.listdir(os.path.join(i_path,folder))
         for file in file_list:
             try:
