@@ -146,10 +146,12 @@ def gen_dtcc(sta_list,sum_file="out.sum",work_dir="./",cc_threshold=0.7,min_link
                     for line in f:
                         line = line.rstrip()
                         path1,arr1,_,path2,arr2,_,cc,aa=re.split(" +",line.rstrip())
-                        eve_folder1 = re.split("\/",path1)[1] # folder name of event
+                        tmp = os.path.split(path1)[0]
+                        eve_folder1 = os.path.split(tmp)[1]
                         evid1 = sum_rev[eve_folder1][0]
                         arr1 =float(arr1)                     # arrival time
-                        eve_folder2 = re.split("\/",path2)[1]
+                        tmp = os.path.split(path2)[0]
+                        eve_folder2 = os.path.split(tmp)[1]
                         evid2 = sum_rev[eve_folder2][0]
                         if evid1 not in evid_list:
                             evid_list.append(evid1)
