@@ -55,8 +55,11 @@ def extract_set_info(pth,sta_file,depth=2):
     """
     logger = logging.getLogger()
     logger.info("Extract_set_info program launched...")
-    if os.path.exists(os.path.join(pth,'setinfo.pkl')):
-        f = open(os.path.join(pth,'setinfo.pkl'),'rb')
+    parent_path = os.path.split(pth)[0]
+    if parent_path=="":
+        parent_path="."
+    if os.path.exists(os.path.join(parent_path,'setinfo.pkl')):
+        f = open(os.path.join(parent_path,'setinfo.pkl'),'rb')
         setinfo = pickle.load(f)
         logger.info("Read in the existed setinfo.pkl and return")
         return setinfo
@@ -117,7 +120,7 @@ def extract_set_info(pth,sta_file,depth=2):
     setinfo["netstas"] = netstas
     setinfo["center"] = [np.mean(stalons),np.mean(stalats)]
     logging.info("extract set info programme done")
-    f = open(os.path.join(pth,"setinfo.pkl"),'wb')
+    f = open(os.path.join(parent_path,"setinfo.pkl"),'wb')
     pickle.dump(setinfo,f)
     f.close()
     return setinfo
